griffin.test.contract.mock-protocol


Stateclj/sprotocol

init-stateclj/s

(init-state this i)

Update the state given a mock is starting with initial state i

Update the state given a mock is starting with initial state i

swap-stateclj/s

(swap-state this f)

Calls f, the method, with the current mock state, replacing with the return value. NOTE: f may be called multiple times so should be free of side effects.

Calls f, the method, with the current mock state, replacing with the return value. NOTE: f may be called multiple times so should be free of side effects.
source

cljdoc builds & hosts documentation for Clojure/Script libraries