griffin.test.contract.protocol


Methodclj/sprotocol

argsclj/s

(args this state)

Return a generator for arguments to call the method in the current state. Do not include this

Return a generator for arguments to call the method in the current state. Do not include `this`

preconditionclj/s

(precondition this state args)

Return truthy if it is valid to call this method with these args in the current state.

Return truthy if it is valid to call this method with these args in the current state.

requiresclj/s

(requires this state)

Return truthy if it is valid to generate a call to this method in the current state.

Return truthy if it is valid to generate a call to this method in the current state.

returnclj/s

(return this state args)

return an instance of Return

return an instance of Return

varclj/s

(var this)

the protocol method var this describes

the protocol method var this describes
source

Modelclj/sprotocol

cleanupclj/s

(cleanup this implementation calls)

Called at the end of a test, with the implementation under test, and the set of calls that were run

Called at the end of a test, with the implementation under test, and the set of calls that were run

gen-methodclj/s

(gen-method this state)

Return a generator for selecting the next method to call

Return a generator for selecting the next method to call

get-methodclj/s

(get-method this v)

Given a protocol method var, return an instance of Method

Given a protocol method var, return an instance of Method

initial-stateclj/s

(initial-state this)

Return a state value

Return a state value

methodsclj/s

(methods this)

Return all Methods

Return all Methods

protocolsclj/s

(protocols this)

The set of protocols this models

The set of protocols this models
source

Returnclj/sprotocol

genclj/s

(gen this)

A generator for mock return values. If not supplied, spec must gen

A generator for mock return values. If not supplied, `spec` must gen

next-stateclj/s

(next-state this)

The next state value after this method returns

The next state value after this method returns

specclj/s

(spec this)

A spec to validate the implementation's return value against

A spec to validate the implementation's return value against
source

cljdoc builds & hosts documentation for Clojure/Script libraries