(args this state)Return a generator for arguments to call the method in the current state. Do not include this
Return a generator for arguments to call the method in the current state. Do not include `this`
(precondition this state args)Return truthy if it is valid to call this method with these args in the current state.
Return truthy if it is valid to call this method with these args in the current state.
(requires this state)Return truthy if it is valid to generate a call to this method in the current state.
Return truthy if it is valid to generate a call to this method in the current state.
(return this state args)return an instance of Return
return an instance of Return
(var this)the protocol method var this describes
the protocol method var this describes
(cleanup this implementation calls)Called at the end of a test, with the implementation under test, and the set of calls that were run
Called at the end of a test, with the implementation under test, and the set of calls that were run
(gen-method this state)Return a generator for selecting the next method to call
Return a generator for selecting the next method to call
(get-method this v)Given a protocol method var, return an instance of Method
Given a protocol method var, return an instance of Method
(initial-state this)Return a state value
Return a state value
(methods this)Return all Methods
Return all Methods
(protocols this)The set of protocols this models
The set of protocols this models
(gen this)A generator for mock return values. If not supplied, spec must gen
A generator for mock return values. If not supplied, `spec` must gen
(next-state this)The next state value after this method returns
The next state value after this method returns
(spec this)A spec to validate the implementation's return value against
A spec to validate the implementation's return value against
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |